==> rtp-1.2.0.tar.gz: rtp_1_2_0/rtp/test/test_timing.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const test_timing_cxx_Version =
    "$Id: test_timing.cxx,v 1.7 2000/12/18 23:44:51 bko Exp $";
// --- Authors ---------------------------------------------------- //
// Kim Le, July 1999
// ---------------------------------------------------------------- //

#include <stdlib.h>
#include <unistd.h>
#include <fstream>

#include "cpLog.h"

#include "rtpTypes.h"
#include "RtpSession.hxx"
#include "VTime.hxx"

#ifdef __vxworks
#include "VThread.h"
#endif

#ifndef __vxworks
int main (int argc, char *argv[])
#else
int sampleUsageMain (char* rmtHost, int rmtPort, int lclPort,
                     int rmtRtcpPort, int lclRtcpPort,
                     int apiPktSize, int netPktSize)
#endif
{
    // setup logfile
    //    cpLogSetLabel ("sampleUsage");
    //    cpLogSetPriority (LOG_DEBUG);

    RtpPayloadType payloadType = rtpPayloadPCMU;

#ifndef __vxworks
    if (argc != 8)
    {
        cerr << "Usage:\n";
        cerr << "sampleUsage host rtpTxPort rtpRxPort rtcpTxPort rtcpRxPort\n";
        return 1;
    }
#endif

    // receiving on localhost on port 5000/5001
    // use seperate RTCP ports for localhost usage
#ifndef __vxworks
    RtpSession stack (argv[1], atoi(argv[2]), atoi(argv[3]),
                      atoi(argv[4]), atoi(argv[5]),
                      payloadType);
#else
RtpSession stack ( rmtHost, rmtPort, lclPort,
    rmtRtcpPort, lclRtcpPort, payloadType);
#endif

    RtpPacket* inPacket = NULL;
    RtpPacket* outPacket = stack.createPacket();
    strncpy (outPacket->getPayloadLoc(), "data", 5);

    int apSize, npSize;

    // acutally usage is 5, but just pretending a big packet
#ifndef __vxworks
    apSize = atoi(argv[6]);
    npSize = atoi(argv[7]);
#else
    apSize = apiPktSize;
    npSize = netPktSize;
#endif

    outPacket->setPayloadUsage (npSize);
    stack.setApiPktSize (apSize);
    stack.setNetworkPktSize (npSize);

    struct timeval curtime[500];

    //    for (int i = 0; 1 || i<500; i++)
    for (int i = 0; i < 500; i++)
    {
        gettimeofday(curtime + i, NULL);

        // receive a packet
        inPacket = stack.receive ();

        stack.transmit (outPacket);
    }

    for (int j = 1; j < 500; j++)
    {
        cout << curtime[j].tv_usec - curtime[j - 1].tv_usec << endl;
    }
    return 0;
}

==> rtp-1.4.0.tar.gz: rtp-1.4.0/rtp/test/test_timing.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const test_timing_cxx_Version =
    "$Id: test_timing.cxx,v 1.11 2001/06/29 21:02:42 bko Exp $";
// --- Authors ---------------------------------------------------- //
// Kim Le, July 1999
// ---------------------------------------------------------------- //

#include <stdlib.h>
#include <unistd.h>
#include <fstream>

#include "cpLog.h"

#include "rtpTypes.h"
#include "RtpSession.hxx"
#include "VTime.hxx"

#ifdef __vxworks
#include "VThread.hxx"
#endif

#ifndef __vxworks
int main (int argc, char *argv[])
#else
int sampleUsageMain (char* rmtHost, int rmtPort, int lclPort,
                     int rmtRtcpPort, int lclRtcpPort,
                     int apiPktSize, int netPktSize)
#endif
{
    // setup logfile
    //    cpLogSetLabel ("sampleUsage");
    //    cpLogSetPriority (LOG_DEBUG);

    RtpPayloadType payloadType = rtpPayloadPCMU;

#ifndef __vxworks
    if (argc != 8)
    {
        cerr << "Usage:\n";
        cerr << "sampleUsage host rtpTxPort rtpRxPort rtcpTxPort rtcpRxPort\n";
        return 1;
    }
#endif

    // receiving on localhost on port 5000/5001
    // use seperate RTCP ports for localhost usage
#ifndef __vxworks
    RtpSession stack (argv[1], atoi(argv[2]), atoi(argv[3]),
                      atoi(argv[4]), atoi(argv[5]),
                      payloadType);
#else
RtpSession stack ( rmtHost, rmtPort, lclPort,
    rmtRtcpPort, lclRtcpPort, payloadType);
#endif

    RtpPacket* inPacket = NULL;
    RtpPacket* outPacket = stack.createPacket();
    strncpy (outPacket->getPayloadLoc(), "data", 5);

    int apSize, npSize;

    // acutally usage is 5, but just pretending a big packet
#ifndef __vxworks
    apSize = atoi(argv[6]);
    npSize = atoi(argv[7]);
#else
    apSize = apiPktSize;
    npSize = netPktSize;
#endif

    outPacket->setPayloadUsage (npSize);
    stack.setApiPktSize (apSize);
    stack.setNetworkPktSize (npSize);

    struct timeval curtime[500];

    //    for (int i = 0; 1 || i<500; i++)
    for (int i = 0; i < 500; i++)
    {
        gettimeofday(curtime + i, NULL);

        // receive a packet
        inPacket = stack.receive ();

        stack.transmit (outPacket);
    }

    for (int j = 1; j < 500; j++)
    {
        cout << curtime[j].tv_usec - curtime[j - 1].tv_usec << endl;
    }
    return 0;
}
